# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six
import urllib3.exceptions


from cohesivenet import Logger
from cohesivenet.exceptions import ApiTypeError, ApiValueError, ApiException


class ConfigurationApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            from cohesivenet.vns3_client import VNS3Client

            api_client = VNS3Client()
        self.api_client = api_client

    def get_config(self, **kwargs):  # noqa: E501
        """get_config  # noqa: E501

        Describe Runtime Configuration for VNS3 Controller  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_config(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ConfigDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_config_with_http_info(**kwargs)  # noqa: E501

    def get_config_with_http_info(self, **kwargs):  # noqa: E501
        """get_config  # noqa: E501

        Describe Runtime Configuration for VNS3 Controller  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_config_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ConfigDetail, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_config" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/config",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ConfigDetail",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_keyset(self, **kwargs):  # noqa: E501
        """get_keyset  # noqa: E501

        Returns status of whether cryptographic credentials, which are used to provide  overlay devices access to the topology, have been generated.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_keyset(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: KeysetDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_keyset_with_http_info(**kwargs)  # noqa: E501

    def get_keyset_with_http_info(self, **kwargs):  # noqa: E501
        """get_keyset  # noqa: E501

        Returns status of whether cryptographic credentials, which are used to provide  overlay devices access to the topology, have been generated.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_keyset_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(KeysetDetail, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_keyset" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/keyset",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="KeysetDetail",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_runtime(self, **kwargs):  # noqa: E501
        """get_runtime  # noqa: E501

        Alias for GET /config  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_runtime(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ConfigDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_runtime_with_http_info(**kwargs)  # noqa: E501

    def get_runtime_with_http_info(self, **kwargs):  # noqa: E501
        """get_runtime  # noqa: E501

        Alias for GET /config  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_runtime_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ConfigDetail, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_runtime" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/runtime",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ConfigDetail",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_ssl_install_status(self, uuid, **kwargs):  # noqa: E501
        """get_ssl_install_status  # noqa: E501

        Get status for ssl installation task  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ssl_install_status(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: uuid of resource (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_ssl_install_status_with_http_info(uuid, **kwargs)  # noqa: E501

    def get_ssl_install_status_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """get_ssl_install_status  # noqa: E501

        Get status for ssl installation task  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ssl_install_status_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: uuid of resource (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["uuid"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ssl_install_status" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'uuid' is set
        if "uuid" not in local_var_params or local_var_params["uuid"] is None:
            raise ApiValueError(
                "Missing the required parameter `uuid` when calling `get_ssl_install_status`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "uuid" in local_var_params:
            path_params["uuid"] = local_var_params["uuid"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/system/ssl/install/{uuid}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_config(self, update_config_request, **kwargs):  # noqa: E501
        """put_config  # noqa: E501

        Provides general information about the manager's topology, license state and  checksums and allows you to set the topology name.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_config(update_config_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateConfigRequest update_config_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ConfigDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_config_with_http_info(
            update_config_request, **kwargs
        )  # noqa: E501

    def put_config_with_http_info(self, update_config_request, **kwargs):  # noqa: E501
        """put_config  # noqa: E501

        Provides general information about the manager's topology, license state and  checksums and allows you to set the topology name.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_config_with_http_info(update_config_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateConfigRequest update_config_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ConfigDetail, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["update_config_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_config" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'update_config_request' is set
        if (
            "update_config_request" not in local_var_params
            or local_var_params["update_config_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `update_config_request` when calling `put_config`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "update_config_request" in local_var_params:
            body_params = local_var_params["update_config_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/config",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ConfigDetail",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_install_ssl_keypair(self, **kwargs):  # noqa: E501
        """put_install_ssl_keypair  # noqa: E501

        Install new SSL cert and key pair  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_install_ssl_keypair(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ServerSSLDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_install_ssl_keypair_with_http_info(**kwargs)  # noqa: E501

    def put_install_ssl_keypair_with_http_info(self, **kwargs):  # noqa: E501
        """put_install_ssl_keypair  # noqa: E501

        Install new SSL cert and key pair  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_install_ssl_keypair_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ServerSSLDetailResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_install_ssl_keypair" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/system/ssl/install",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ServerSSLDetailResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_keyset(self, update_keyset_request, **kwargs):  # noqa: E501
        """put_keyset  # noqa: E501

        Generates or fetches cryptographic credentials which are used to provide overlay devices access to the topology.  Keyset generation happens in background. Poll on GET /keyset in_progress value.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_keyset(update_keyset_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateKeysetRequest update_keyset_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: KeysetDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_keyset_with_http_info(
            update_keyset_request, **kwargs
        )  # noqa: E501

    def put_keyset_with_http_info(self, update_keyset_request, **kwargs):  # noqa: E501
        """put_keyset  # noqa: E501

        Generates or fetches cryptographic credentials which are used to provide overlay devices access to the topology.  Keyset generation happens in background. Poll on GET /keyset in_progress value.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_keyset_with_http_info(update_keyset_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateKeysetRequest update_keyset_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(KeysetDetail, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["update_keyset_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_keyset" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'update_keyset_request' is set
        if (
            "update_keyset_request" not in local_var_params
            or local_var_params["update_keyset_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `update_keyset_request` when calling `put_keyset`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "update_keyset_request" in local_var_params:
            body_params = local_var_params["update_keyset_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/keyset",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="KeysetDetail",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_update_admin_ui(
        self, update_admin_ui_settings_request, **kwargs
    ):  # noqa: E501
        """put_update_admin_ui  # noqa: E501

        Update Admin UI settings. Enable/Disable and set credentials.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_update_admin_ui(update_admin_ui_settings_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateAdminUISettingsRequest update_admin_ui_settings_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AdminUISettingsDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_update_admin_ui_with_http_info(
            update_admin_ui_settings_request, **kwargs
        )  # noqa: E501

    def put_update_admin_ui_with_http_info(
        self, update_admin_ui_settings_request, **kwargs
    ):  # noqa: E501
        """put_update_admin_ui  # noqa: E501

        Update Admin UI settings. Enable/Disable and set credentials.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_update_admin_ui_with_http_info(update_admin_ui_settings_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateAdminUISettingsRequest update_admin_ui_settings_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AdminUISettingsDetail, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["update_admin_ui_settings_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_update_admin_ui" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'update_admin_ui_settings_request' is set
        if (
            "update_admin_ui_settings_request" not in local_var_params
            or local_var_params["update_admin_ui_settings_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `update_admin_ui_settings_request` when calling `put_update_admin_ui`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "update_admin_ui_settings_request" in local_var_params:
            body_params = local_var_params["update_admin_ui_settings_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/admin_ui",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="AdminUISettingsDetail",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_update_api_password(self, update_password_request, **kwargs):  # noqa: E501
        """put_update_api_password  # noqa: E501

        Allows you to change the API password/secret key.  To change the Web UI password (or username) use PUT admin_ui.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_update_api_password(update_password_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdatePasswordRequest update_password_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PasswordResetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_update_api_password_with_http_info(
            update_password_request, **kwargs
        )  # noqa: E501

    def put_update_api_password_with_http_info(
        self, update_password_request, **kwargs
    ):  # noqa: E501
        """put_update_api_password  # noqa: E501

        Allows you to change the API password/secret key.  To change the Web UI password (or username) use PUT admin_ui.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_update_api_password_with_http_info(update_password_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdatePasswordRequest update_password_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PasswordResetResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["update_password_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_update_api_password" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'update_password_request' is set
        if (
            "update_password_request" not in local_var_params
            or local_var_params["update_password_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `update_password_request` when calling `put_update_api_password`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "update_password_request" in local_var_params:
            body_params = local_var_params["update_password_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/api_password",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="PasswordResetResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_upload_ssl_keypair(self, update_server_ssl_request, **kwargs):  # noqa: E501
        """put_upload_ssl_keypair  # noqa: E501

        Upload new SSL cert and key pair  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_upload_ssl_keypair(update_server_ssl_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateServerSSLRequest update_server_ssl_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_upload_ssl_keypair_with_http_info(
            update_server_ssl_request, **kwargs
        )  # noqa: E501

    def put_upload_ssl_keypair_with_http_info(
        self, update_server_ssl_request, **kwargs
    ):  # noqa: E501
        """put_upload_ssl_keypair  # noqa: E501

        Upload new SSL cert and key pair  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_upload_ssl_keypair_with_http_info(update_server_ssl_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateServerSSLRequest update_server_ssl_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["update_server_ssl_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_upload_ssl_keypair" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'update_server_ssl_request' is set
        if (
            "update_server_ssl_request" not in local_var_params
            or local_var_params["update_server_ssl_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `update_server_ssl_request` when calling `put_upload_ssl_keypair`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "update_server_ssl_request" in local_var_params:
            body_params = local_var_params["update_server_ssl_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/system/ssl/keypair",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def try_get_keyset(self, **kwargs):  # noqa: E501
        """try_get_keyset  # noqa: E501

        Wraps get_keyset for unlicensed error.
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.try_get_keyset(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: KeysetDetail or None
        """
        try:
            return self.get_keyset(**kwargs)
        except ApiException as e:
            if e.status == 403 and "must be licensed" in e.get_error_message().lower():
                return None
            raise e

    def wait_for_keyset(self, retry_timeout=2.0, timeout=60):
        """wait_for_keyset

        Wait for keyset to be generated on server
        """
        import time

        start_time = time.time()

        target_host = self.api_client.host_uri
        while time.time() - start_time < timeout:
            try:
                keyset_data = self.get_keyset()
                keyset_response = keyset_data.response
                if (
                    keyset_response
                    and (not keyset_response.in_progress)
                    and keyset_response.keyset_present
                ):
                    return keyset_data
                Logger.debug("Keyset not present. Retrying.", host=target_host)
                time.sleep(retry_timeout)
            except (
                urllib3.exceptions.ConnectTimeoutError,
                urllib3.exceptions.NewConnectionError,
                urllib3.exceptions.MaxRetryError,
            ):
                Logger.debug(
                    "API connection error fetching keyset. Retrying.", host=target_host
                )
                time.sleep(retry_timeout)
                continue
        raise ApiException(
            reason="Failed to fetch keyset. Timeout %s seconds." % timeout
        )



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class HaConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "type": "str",
        "status": "str",
        "last_sync": "str",
        "last_sync_update": "str",
        "primary_ip": "str",
        "backup_ip": "str",
    }

    attribute_map = {
        "type": "type",
        "status": "status",
        "last_sync": "last_sync",
        "last_sync_update": "last_sync_update",
        "primary_ip": "primary_ip",
        "backup_ip": "backup_ip",
    }

    def __init__(
        self,
        type=None,
        status=None,
        last_sync=None,
        last_sync_update=None,
        primary_ip=None,
        backup_ip=None,
    ):  # noqa: E501
        """HaConfig - a model defined in OpenAPI"""  # noqa: E501

        self._type = None
        self._status = None
        self._last_sync = None
        self._last_sync_update = None
        self._primary_ip = None
        self._backup_ip = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if status is not None:
            self.status = status
        self.last_sync = last_sync
        self.last_sync_update = last_sync_update
        self.primary_ip = primary_ip
        self.backup_ip = backup_ip

    @property
    def type(self):
        """Gets the type of this HaConfig.  # noqa: E501

        primary or backup  # noqa: E501

        :return: The type of this HaConfig.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type_str):
        """Sets the type of this HaConfig.

        primary or backup  # noqa: E501

        :param type: The type of this HaConfig.  # noqa: E501
        :type: str
        """
        self._type = type_str

    @property
    def status(self):
        """Gets the status of this HaConfig.  # noqa: E501

        initialised or not initialised  # noqa: E501

        :return: The status of this HaConfig.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this HaConfig.

        initialised or not initialised  # noqa: E501

        :param status: The status of this HaConfig.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def last_sync(self):
        """Gets the last_sync of this HaConfig.  # noqa: E501


        :return: The last_sync of this HaConfig.  # noqa: E501
        :rtype: str
        """
        return self._last_sync

    @last_sync.setter
    def last_sync(self, last_sync):
        """Sets the last_sync of this HaConfig.


        :param last_sync: The last_sync of this HaConfig.  # noqa: E501
        :type: str
        """

        self._last_sync = last_sync

    @property
    def last_sync_update(self):
        """Gets the last_sync_update of this HaConfig.  # noqa: E501


        :return: The last_sync_update of this HaConfig.  # noqa: E501
        :rtype: str
        """
        return self._last_sync_update

    @last_sync_update.setter
    def last_sync_update(self, last_sync_update):
        """Sets the last_sync_update of this HaConfig.


        :param last_sync_update: The last_sync_update of this HaConfig.  # noqa: E501
        :type: str
        """

        self._last_sync_update = last_sync_update

    @property
    def primary_ip(self):
        """Gets the primary_ip of this HaConfig.  # noqa: E501


        :return: The primary_ip of this HaConfig.  # noqa: E501
        :rtype: str
        """
        return self._primary_ip

    @primary_ip.setter
    def primary_ip(self, primary_ip):
        """Sets the primary_ip of this HaConfig.


        :param primary_ip: The primary_ip of this HaConfig.  # noqa: E501
        :type: str
        """

        self._primary_ip = primary_ip

    @property
    def backup_ip(self):
        """Gets the backup_ip of this HaConfig.  # noqa: E501


        :return: The backup_ip of this HaConfig.  # noqa: E501
        :rtype: str
        """
        return self._backup_ip

    @backup_ip.setter
    def backup_ip(self, backup_ip):
        """Sets the backup_ip of this HaConfig.


        :param backup_ip: The backup_ip of this HaConfig.  # noqa: E501
        :type: str
        """

        self._backup_ip = backup_ip

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HaConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import ipaddress
from typing import List


class NetworkMathException(Exception):
    pass


def get_default_gateway(subnet_cidr: str) -> str:
    return str(next(ipaddress.ip_network(subnet_cidr).hosts()))


def calculate_next_subnets(
    prefix_length: int, take: int, cidr: str, after_subnet: str = None
) -> List[str]:
    """Calculate the next {take} subnets of prefix length {prefix_length} for network cidr {cidr}

    Arguments:
        prefix_length {int}
        take {int}
        cidr {str}

    Returns:
        List[str]
    """
    network = ipaddress.ip_network(cidr)
    subnets = network.subnets(new_prefix=prefix_length)

    if after_subnet:
        try:
            # iterate until next in sequence is subnet after
            next(sn for sn in subnets if sn == ipaddress.ip_network(after_subnet))
        except (StopIteration, ValueError):
            raise NetworkMathException(
                "Subnet %s not found in subnets of prefix "
                "length %s for parent network %s." % (after_subnet, prefix_length, cidr)
            )

    try:
        return [next(subnets) for _ in range(take)]
    except StopIteration:
        raise NetworkMathException(
            "Cant take %s subnets [prefix:%s] from parent "
            "net %s [after subnet:%s]" % (take, prefix_length, cidr, after_subnet)
        )


def subnet_contains_ipv4(ip_address: str, subnet: str):
    """subnet_contains Check if ip address in subnet

    Arguments:
        ip_address {str} -- string
        subnet {str}

    Returns:
        bool
    """
    return ipaddress.ip_address(ip_address) in ipaddress.ip_network(subnet)



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class UpdatePeerRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"id": "str", "name": "str", "overlay_mtu": "int", "force": "bool"}

    attribute_map = {
        "id": "id",
        "name": "name",
        "overlay_mtu": "overlay_mtu",
        "force": "force",
    }

    def __init__(self, id=None, name=None, overlay_mtu=None, force=None):  # noqa: E501
        """UpdatePeerRequest - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._name = None
        self._overlay_mtu = None
        self._force = None
        self.discriminator = None

        self.id = id
        self.name = name
        if overlay_mtu is not None:
            self.overlay_mtu = overlay_mtu
        if force is not None:
            self.force = force

    @property
    def id(self):
        """Gets the id of this UpdatePeerRequest.  # noqa: E501

        Manager ID as an integer of the the manager you are peering with,  NOT the id of the one you are calling from   # noqa: E501

        :return: The id of this UpdatePeerRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UpdatePeerRequest.

        Manager ID as an integer of the the manager you are peering with,  NOT the id of the one you are calling from   # noqa: E501

        :param id: The id of this UpdatePeerRequest.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this UpdatePeerRequest.  # noqa: E501

        IP address or host name of the one you are peering with.  # noqa: E501

        :return: The name of this UpdatePeerRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdatePeerRequest.

        IP address or host name of the one you are peering with.  # noqa: E501

        :param name: The name of this UpdatePeerRequest.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError(
                "Invalid value for `name`, must not be `None`"
            )  # noqa: E501

        self._name = name

    @property
    def overlay_mtu(self):
        """Gets the overlay_mtu of this UpdatePeerRequest.  # noqa: E501

        link MTU between 500 and 4800  # noqa: E501

        :return: The overlay_mtu of this UpdatePeerRequest.  # noqa: E501
        :rtype: int
        """
        return self._overlay_mtu

    @overlay_mtu.setter
    def overlay_mtu(self, overlay_mtu):
        """Sets the overlay_mtu of this UpdatePeerRequest.

        link MTU between 500 and 4800  # noqa: E501

        :param overlay_mtu: The overlay_mtu of this UpdatePeerRequest.  # noqa: E501
        :type: int
        """
        if overlay_mtu is not None and overlay_mtu > 48000:  # noqa: E501
            raise ValueError(
                "Invalid value for `overlay_mtu`, must be a value less than or equal to `48000`"
            )  # noqa: E501
        if overlay_mtu is not None and overlay_mtu < 500:  # noqa: E501
            raise ValueError(
                "Invalid value for `overlay_mtu`, must be a value greater than or equal to `500`"
            )  # noqa: E501

        self._overlay_mtu = overlay_mtu

    @property
    def force(self):
        """Gets the force of this UpdatePeerRequest.  # noqa: E501

        Setting false will NOT finalize the peering operation.  A peer \"reconfigure\" call would then be required. Default is true   # noqa: E501

        :return: The force of this UpdatePeerRequest.  # noqa: E501
        :rtype: bool
        """
        return self._force

    @force.setter
    def force(self, force):
        """Sets the force of this UpdatePeerRequest.

        Setting false will NOT finalize the peering operation.  A peer \"reconfigure\" call would then be required. Default is true   # noqa: E501

        :param force: The force of this UpdatePeerRequest.  # noqa: E501
        :type: bool
        """

        self._force = force

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdatePeerRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class LicenseParameters(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "subnet": "str",
        "controllers": "list[str]",
        "clients": "list[str]",
        "my_manager_vip": "str",
    }

    attribute_map = {
        "subnet": "subnet",
        "controllers": "controllers",
        "clients": "clients",
        "my_manager_vip": "my_manager_vip",
    }

    def __init__(
        self, subnet=None, controllers=None, clients=None, my_manager_vip=None
    ):  # noqa: E501
        """LicenseParameters - a model defined in OpenAPI"""  # noqa: E501

        self._subnet = None
        self._controllers = None
        self._clients = None
        self._my_manager_vip = None
        self.discriminator = None

        if subnet is not None:
            self.subnet = subnet
        if controllers is not None:
            self.controllers = controllers
        if clients is not None:
            self.clients = clients
        if my_manager_vip is not None:
            self.my_manager_vip = my_manager_vip

    @property
    def subnet(self):
        """Gets the subnet of this LicenseParameters.  # noqa: E501


        :return: The subnet of this LicenseParameters.  # noqa: E501
        :rtype: str
        """
        return self._subnet

    @subnet.setter
    def subnet(self, subnet):
        """Sets the subnet of this LicenseParameters.


        :param subnet: The subnet of this LicenseParameters.  # noqa: E501
        :type: str
        """

        self._subnet = subnet

    @property
    def controllers(self):
        """Gets the controllers of this LicenseParameters.  # noqa: E501

        IP addresses of VNS3 controllers in topology  # noqa: E501

        :return: The controllers of this LicenseParameters.  # noqa: E501
        :rtype: list[str]
        """
        return self._controllers

    @controllers.setter
    def controllers(self, controllers):
        """Sets the controllers of this LicenseParameters.

        IP addresses of VNS3 controllers in topology  # noqa: E501

        :param controllers: The controllers of this LicenseParameters.  # noqa: E501
        :type: list[str]
        """

        self._controllers = controllers

    @property
    def clients(self):
        """Gets the clients of this LicenseParameters.  # noqa: E501

        IP addresses of clients in topology  # noqa: E501

        :return: The clients of this LicenseParameters.  # noqa: E501
        :rtype: list[str]
        """
        return self._clients

    @clients.setter
    def clients(self, clients):
        """Sets the clients of this LicenseParameters.

        IP addresses of clients in topology  # noqa: E501

        :param clients: The clients of this LicenseParameters.  # noqa: E501
        :type: list[str]
        """

        self._clients = clients

    @property
    def my_manager_vip(self):
        """Gets the my_manager_vip of this LicenseParameters.  # noqa: E501


        :return: The my_manager_vip of this LicenseParameters.  # noqa: E501
        :rtype: str
        """
        return self._my_manager_vip

    @my_manager_vip.setter
    def my_manager_vip(self, my_manager_vip):
        """Sets the my_manager_vip of this LicenseParameters.


        :param my_manager_vip: The my_manager_vip of this LicenseParameters.  # noqa: E501
        :type: str
        """

        self._my_manager_vip = my_manager_vip

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LicenseParameters):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

import cohesivenet
from cohesivenet.api.vns3.snapshots_api import SnapshotsApi  # noqa: E501
from cohesivenet.rest import ApiException


class TestSnapshotsApi(object):
    """SnapshotsApi unit test stubs"""

    @pytest.mark.licensed
    def test_delete_snapshot(self):
        """Test case for delete_snapshot

        """
        pass

    @pytest.mark.licensed
    def test_get_download_snapshot(self):
        """Test case for get_download_snapshot

        """
        pass

    @pytest.mark.licensed
    def test_get_snapshots(self):
        """Test case for get_snapshots

        """
        pass

    @pytest.mark.licensed
    def test_post_create_snapshot(self):
        """Test case for post_create_snapshot

        """
        pass

    def test_put_import_snapshot(self):
        """Test case for put_import_snapshot

        """
        pass



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cohesivenet.exceptions import ApiTypeError, ApiValueError


class LicensingApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            from cohesivenet.vns3_client import VNS3Client

            api_client = VNS3Client()
        self.api_client = api_client

    def get_license(self, **kwargs):  # noqa: E501
        """get_license  # noqa: E501

        Get license details  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_license(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: LicenseDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_license_with_http_info(**kwargs)  # noqa: E501

    def get_license_with_http_info(self, **kwargs):  # noqa: E501
        """get_license  # noqa: E501

        Get license details  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_license_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(LicenseDetail, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_license" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/license",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="LicenseDetail",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_license_upgrade(self, body, **kwargs):  # noqa: E501
        """put_license_upgrade  # noqa: E501

        Upload new license to controller  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_license_upgrade(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param file body: License file (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UpgradeLicenseResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_license_upgrade_with_http_info(body, **kwargs)  # noqa: E501

    def put_license_upgrade_with_http_info(self, body, **kwargs):  # noqa: E501
        """put_license_upgrade  # noqa: E501

        Upload new license to controller  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_license_upgrade_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param file body: License file (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UpgradeLicenseResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_license_upgrade" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in local_var_params or local_var_params["body"] is None:
            raise ApiValueError(
                "Missing the required parameter `body` when calling `put_license_upgrade`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in local_var_params:
            body_params = local_var_params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["text/plain"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/license/upgrade",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UpgradeLicenseResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_set_license_parameters(
        self, update_license_parameters_request, **kwargs
    ):  # noqa: E501
        """put_set_license_parameters  # noqa: E501

        Set and accept license parameters. Triggers reboot. Irreversible operation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_set_license_parameters(update_license_parameters_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateLicenseParametersRequest update_license_parameters_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: LicenseParametersDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_set_license_parameters_with_http_info(
            update_license_parameters_request, **kwargs
        )  # noqa: E501

    def put_set_license_parameters_with_http_info(
        self, update_license_parameters_request, **kwargs
    ):  # noqa: E501
        """put_set_license_parameters  # noqa: E501

        Set and accept license parameters. Triggers reboot. Irreversible operation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_set_license_parameters_with_http_info(update_license_parameters_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateLicenseParametersRequest update_license_parameters_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(LicenseParametersDetail, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["update_license_parameters_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_set_license_parameters" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'update_license_parameters_request' is set
        if (
            "update_license_parameters_request" not in local_var_params
            or local_var_params["update_license_parameters_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `update_license_parameters_request` when calling `put_set_license_parameters`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "update_license_parameters_request" in local_var_params:
            body_params = local_var_params["update_license_parameters_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/license/parameters",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="LicenseParametersDetail",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def upload_license(self, body, **kwargs):  # noqa: E501
        """upload_license  # noqa: E501

        License a VNS3 Controller to be a part of a specific topology. Must not be licensed already.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_license(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param file body: License file (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: InitLicenseDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.upload_license_with_http_info(body, **kwargs)  # noqa: E501

    def upload_license_with_http_info(self, body, **kwargs):  # noqa: E501
        """upload_license  # noqa: E501

        License a VNS3 Controller to be a part of a specific topology. Must not be licensed already.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_license_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param file body: License file (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(InitLicenseDetail, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_license" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in local_var_params or local_var_params["body"] is None:
            raise ApiValueError(
                "Missing the required parameter `body` when calling `upload_license`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in local_var_params:
            body_params = local_var_params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["text/plain"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/license",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="InitLicenseDetail",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class UpgradeLicenseResponseResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "finalized": "bool",
        "uniq": "str",
        "license": "str",
        "new_clientpacks": "int",
        "new_managers": "int",
    }

    attribute_map = {
        "finalized": "finalized",
        "uniq": "uniq",
        "license": "license",
        "new_clientpacks": "new_clientpacks",
        "new_managers": "new_managers",
    }

    def __init__(
        self,
        finalized=None,
        uniq=None,
        license=None,
        new_clientpacks=None,
        new_managers=None,
    ):  # noqa: E501
        """UpgradeLicenseResponseResponse - a model defined in OpenAPI"""  # noqa: E501

        self._finalized = None
        self._uniq = None
        self._license = None
        self._new_clientpacks = None
        self._new_managers = None
        self.discriminator = None

        if finalized is not None:
            self.finalized = finalized
        if uniq is not None:
            self.uniq = uniq
        if license is not None:
            self.license = license
        if new_clientpacks is not None:
            self.new_clientpacks = new_clientpacks
        if new_managers is not None:
            self.new_managers = new_managers

    @property
    def finalized(self):
        """Gets the finalized of this UpgradeLicenseResponseResponse.  # noqa: E501


        :return: The finalized of this UpgradeLicenseResponseResponse.  # noqa: E501
        :rtype: bool
        """
        return self._finalized

    @finalized.setter
    def finalized(self, finalized):
        """Sets the finalized of this UpgradeLicenseResponseResponse.


        :param finalized: The finalized of this UpgradeLicenseResponseResponse.  # noqa: E501
        :type: bool
        """

        self._finalized = finalized

    @property
    def uniq(self):
        """Gets the uniq of this UpgradeLicenseResponseResponse.  # noqa: E501

        new sha1 hash of license  # noqa: E501

        :return: The uniq of this UpgradeLicenseResponseResponse.  # noqa: E501
        :rtype: str
        """
        return self._uniq

    @uniq.setter
    def uniq(self, uniq):
        """Sets the uniq of this UpgradeLicenseResponseResponse.

        new sha1 hash of license  # noqa: E501

        :param uniq: The uniq of this UpgradeLicenseResponseResponse.  # noqa: E501
        :type: str
        """

        self._uniq = uniq

    @property
    def license(self):
        """Gets the license of this UpgradeLicenseResponseResponse.  # noqa: E501

        State of license, accepted, in-progress, failed  # noqa: E501

        :return: The license of this UpgradeLicenseResponseResponse.  # noqa: E501
        :rtype: str
        """
        return self._license

    @license.setter
    def license(self, license):
        """Sets the license of this UpgradeLicenseResponseResponse.

        State of license, accepted, in-progress, failed  # noqa: E501

        :param license: The license of this UpgradeLicenseResponseResponse.  # noqa: E501
        :type: str
        """

        self._license = license

    @property
    def new_clientpacks(self):
        """Gets the new_clientpacks of this UpgradeLicenseResponseResponse.  # noqa: E501


        :return: The new_clientpacks of this UpgradeLicenseResponseResponse.  # noqa: E501
        :rtype: int
        """
        return self._new_clientpacks

    @new_clientpacks.setter
    def new_clientpacks(self, new_clientpacks):
        """Sets the new_clientpacks of this UpgradeLicenseResponseResponse.


        :param new_clientpacks: The new_clientpacks of this UpgradeLicenseResponseResponse.  # noqa: E501
        :type: int
        """

        self._new_clientpacks = new_clientpacks

    @property
    def new_managers(self):
        """Gets the new_managers of this UpgradeLicenseResponseResponse.  # noqa: E501


        :return: The new_managers of this UpgradeLicenseResponseResponse.  # noqa: E501
        :rtype: int
        """
        return self._new_managers

    @new_managers.setter
    def new_managers(self, new_managers):
        """Sets the new_managers of this UpgradeLicenseResponseResponse.


        :param new_managers: The new_managers of this UpgradeLicenseResponseResponse.  # noqa: E501
        :type: int
        """

        self._new_managers = new_managers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpgradeLicenseResponseResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from cohesivenet.models.access_token import AccessToken
from cohesivenet.models.access_token_detail import AccessTokenDetail
from cohesivenet.models.access_token_list_response import AccessTokenListResponse
from cohesivenet.models.access_url import AccessUrl
from cohesivenet.models.access_url_detail import AccessUrlDetail
from cohesivenet.models.access_url_list_response import AccessUrlListResponse
from cohesivenet.models.activate_ha_request import ActivateHaRequest
from cohesivenet.models.add_clientpack_request import AddClientpackRequest
from cohesivenet.models.admin_ui_settings_detail import AdminUISettingsDetail
from cohesivenet.models.admin_ui_settings_detail_response import (
    AdminUISettingsDetailResponse,
)
from cohesivenet.models.alert import Alert
from cohesivenet.models.alert_detail_response import AlertDetailResponse
from cohesivenet.models.alerts_list_response import AlertsListResponse
from cohesivenet.models.bgp_peer import BGPPeer
from cohesivenet.models.bulk_client_reset_status import BulkClientResetStatus
from cohesivenet.models.bulk_client_reset_status_response import (
    BulkClientResetStatusResponse,
)
from cohesivenet.models.calculate_next_clientpack_request import (
    CalculateNextClientpackRequest,
)
from cohesivenet.models.client_pack import ClientPack
from cohesivenet.models.clientpack_detail import ClientpackDetail
from cohesivenet.models.clientpack_detail_response import ClientpackDetailResponse
from cohesivenet.models.clientpack_list_response import ClientpackListResponse
from cohesivenet.models.clientpack_status import ClientpackStatus
from cohesivenet.models.clientpack_status_response import ClientpackStatusResponse
from cohesivenet.models.clientpack_tag_key_request import ClientpackTagKeyRequest
from cohesivenet.models.clientpack_tags import ClientpackTags
from cohesivenet.models.clientpack_tags_response import ClientpackTagsResponse
from cohesivenet.models.cloud_info import CloudInfo
from cohesivenet.models.cloud_info_detail import CloudInfoDetail
from cohesivenet.models.commit_container_request import CommitContainerRequest
from cohesivenet.models.config_detail import ConfigDetail
from cohesivenet.models.configure_peer_request import ConfigurePeerRequest
from cohesivenet.models.connected_subnets_detail_response import (
    ConnectedSubnetsDetailResponse,
)
from cohesivenet.models.container import Container
from cohesivenet.models.container_image import ContainerImage
from cohesivenet.models.container_image_list import ContainerImageList
from cohesivenet.models.container_image_list_response import ContainerImageListResponse
from cohesivenet.models.container_logs import ContainerLogs
from cohesivenet.models.container_logs_response import ContainerLogsResponse
from cohesivenet.models.container_system_action_request import (
    ContainerSystemActionRequest,
)
from cohesivenet.models.container_system_ip import ContainerSystemIP
from cohesivenet.models.container_system_ip_list import ContainerSystemIPList
from cohesivenet.models.container_system_ip_list_response import (
    ContainerSystemIPListResponse,
)
from cohesivenet.models.container_system_status import ContainerSystemStatus
from cohesivenet.models.container_system_status_detail_response import (
    ContainerSystemStatusDetailResponse,
)
from cohesivenet.models.create_api_token_request import CreateAPITokenRequest
from cohesivenet.models.create_access_url_request import CreateAccessURLRequest
from cohesivenet.models.create_alert_request import CreateAlertRequest
from cohesivenet.models.create_bgp_peer_request import CreateBGPPeerRequest
from cohesivenet.models.create_clientpack_tag_request import CreateClientpackTagRequest
from cohesivenet.models.create_container_image_detail import CreateContainerImageDetail
from cohesivenet.models.create_container_image_response import (
    CreateContainerImageResponse,
)
from cohesivenet.models.create_fw_subgroup_request import CreateFWSubgroupRequest
from cohesivenet.models.create_firewall_rule_request import CreateFirewallRuleRequest
from cohesivenet.models.create_image_detail import CreateImageDetail
from cohesivenet.models.create_image_detail_response import CreateImageDetailResponse
from cohesivenet.models.create_ipsec_endpoint_request import CreateIpsecEndpointRequest
from cohesivenet.models.create_ipsec_tunnel_request import CreateIpsecTunnelRequest
from cohesivenet.models.create_peer_request import CreatePeerRequest
from cohesivenet.models.create_route_request import CreateRouteRequest
from cohesivenet.models.create_snapshot_request import CreateSnapshotRequest
from cohesivenet.models.delete_container_detail import DeleteContainerDetail
from cohesivenet.models.delete_container_detail_response import (
    DeleteContainerDetailResponse,
)
from cohesivenet.models.delete_container_image_detail import DeleteContainerImageDetail
from cohesivenet.models.delete_container_image_detail_response import (
    DeleteContainerImageDetailResponse,
)
from cohesivenet.models.delete_firewall_rule_request import DeleteFirewallRuleRequest
from cohesivenet.models.disconnet_client_request import DisconnetClientRequest
from cohesivenet.models.error_response import ErrorResponse
from cohesivenet.models.error_detail import ErrorDetail
from cohesivenet.models.expire_request import ExpireRequest
from cohesivenet.models.firewall_fw_set import FirewallFWSet
from cohesivenet.models.firewall_fw_set_list_response import FirewallFWSetListResponse
from cohesivenet.models.firewall_rule_list_response import FirewallRuleListResponse
from cohesivenet.models.firewall_rule_operation_data import FirewallRuleOperationData
from cohesivenet.models.firewall_rule_operation_response import (
    FirewallRuleOperationResponse,
)
from cohesivenet.models.firewall_subgroup_list_response import (
    FirewallSubgroupListResponse,
)
from cohesivenet.models.gre_endpoint_detail import GREEndpointDetail
from cohesivenet.models.gre_endpoint_list_response import GREEndpointListResponse
from cohesivenet.models.ha_config import HaConfig
from cohesivenet.models.ha_detail import HaDetail
from cohesivenet.models.ha_sync_status import HaSyncStatus
from cohesivenet.models.ha_sync_status_response import HaSyncStatusResponse
from cohesivenet.models.ha_uuid import HaUUID
from cohesivenet.models.haid import Haid
from cohesivenet.models.init_ha_request import InitHaRequest
from cohesivenet.models.init_license_detail import InitLicenseDetail
from cohesivenet.models.interface_action_request import InterfaceActionRequest
from cohesivenet.models.ipsec_local_endpoint import IpsecLocalEndpoint
from cohesivenet.models.ipsec_remote_endpoint import IpsecRemoteEndpoint
from cohesivenet.models.ipsec_remote_endpoint_detail import IpsecRemoteEndpointDetail
from cohesivenet.models.ipsec_system_detail import IpsecSystemDetail
from cohesivenet.models.ipsec_system_detail_response import IpsecSystemDetailResponse
from cohesivenet.models.ipsec_tunnel import IpsecTunnel
from cohesivenet.models.ipsec_tunnel_detail import IpsecTunnelDetail
from cohesivenet.models.ipsec_tunnel_list_response_key_value import (
    IpsecTunnelListResponseKeyValue,
)
from cohesivenet.models.ipsec_tunnel_params import IpsecTunnelParams
from cohesivenet.models.keyset_detail import KeysetDetail
from cohesivenet.models.keyset_status import KeysetStatus
from cohesivenet.models.license import License
from cohesivenet.models.license_container_details import LicenseContainerDetails
from cohesivenet.models.license_detail import LicenseDetail
from cohesivenet.models.license_initial import LicenseInitial
from cohesivenet.models.license_parameters import LicenseParameters
from cohesivenet.models.license_parameters_detail import LicenseParametersDetail
from cohesivenet.models.license_parameters_state import LicenseParametersState
from cohesivenet.models.link_event import LinkEvent
from cohesivenet.models.link_history import LinkHistory
from cohesivenet.models.link_history_detail import LinkHistoryDetail
from cohesivenet.models.overlay_client import OverlayClient
from cohesivenet.models.overlay_clients_list_response import OverlayClientsListResponse
from cohesivenet.models.overlay_ip_address import OverlayIPAddress
from cohesivenet.models.password_reset_response import PasswordResetResponse
from cohesivenet.models.password_reset_response_response import (
    PasswordResetResponseResponse,
)
from cohesivenet.models.peer_self_request import PeerSelfRequest
from cohesivenet.models.peers_detail import PeersDetail
from cohesivenet.models.peers_detail_response import PeersDetailResponse
from cohesivenet.models.reboot_request import RebootRequest
from cohesivenet.models.reinit_firewall_request import ReinitFirewallRequest
from cohesivenet.models.reinit_request import ReinitRequest
from cohesivenet.models.remote_support_status import RemoteSupportStatus
from cohesivenet.models.remote_support_status_response import (
    RemoteSupportStatusResponse,
)
from cohesivenet.models.reset_overlay_client_request import ResetOverlayClientRequest
from cohesivenet.models.restart_request import RestartRequest
from cohesivenet.models.restart_status import RestartStatus
from cohesivenet.models.restart_status_response import RestartStatusResponse
from cohesivenet.models.route import Route
from cohesivenet.models.routes_list_response import RoutesListResponse
from cohesivenet.models.run_container_detail import RunContainerDetail
from cohesivenet.models.run_container_detail_response import RunContainerDetailResponse
from cohesivenet.models.running_containers_detail import RunningContainersDetail
from cohesivenet.models.running_containers_detail_network_settings import (
    RunningContainersDetailNetworkSettings,
)
from cohesivenet.models.running_containers_detail_response import (
    RunningContainersDetailResponse,
)
from cohesivenet.models.running_containers_detail_state import (
    RunningContainersDetailState,
)
from cohesivenet.models.runtime_config import RuntimeConfig
from cohesivenet.models.runtime_status import RuntimeStatus
from cohesivenet.models.runtime_status_detail import RuntimeStatusDetail
from cohesivenet.models.server_ssl_detail import ServerSSLDetail
from cohesivenet.models.server_ssl_detail_response import ServerSSLDetailResponse
from cohesivenet.models.simple_boolean_response import SimpleBooleanResponse
from cohesivenet.models.simple_status_response import SimpleStatusResponse
from cohesivenet.models.simple_status_response_response import (
    SimpleStatusResponseResponse,
)
from cohesivenet.models.simple_string_response import SimpleStringResponse
from cohesivenet.models.snapshot import Snapshot
from cohesivenet.models.snapshot_import_status import SnapshotImportStatus
from cohesivenet.models.snapshot_import_status_response import (
    SnapshotImportStatusResponse,
)
from cohesivenet.models.snapshots_detail_response import SnapshotsDetailResponse
from cohesivenet.models.snapshots_list import SnapshotsList
from cohesivenet.models.snapshots_list_response import SnapshotsListResponse
from cohesivenet.models.stop_container_detail import StopContainerDetail
from cohesivenet.models.stop_container_detail_response import (
    StopContainerDetailResponse,
)
from cohesivenet.models.system_interface import SystemInterface
from cohesivenet.models.system_interface_detail import SystemInterfaceDetail
from cohesivenet.models.system_interface_list_response import (
    SystemInterfaceListResponse,
)
from cohesivenet.models.system_ping import SystemPing
from cohesivenet.models.system_ping_detail import SystemPingDetail
from cohesivenet.models.system_status import SystemStatus
from cohesivenet.models.system_status_detail import SystemStatusDetail
from cohesivenet.models.task_status import TaskStatus
from cohesivenet.models.task_status_detail import TaskStatusDetail
from cohesivenet.models.topology import Topology
from cohesivenet.models.update_admin_ui_settings_request import (
    UpdateAdminUISettingsRequest,
)
from cohesivenet.models.update_alert_request import UpdateAlertRequest
from cohesivenet.models.update_bgp_peer_connection_request import (
    UpdateBGPPeerConnectionRequest,
)
from cohesivenet.models.update_clientpacks_status import UpdateClientpacksStatus
from cohesivenet.models.update_clientpacks_status_response import (
    UpdateClientpacksStatusResponse,
)
from cohesivenet.models.update_config_clientpack_request import (
    UpdateConfigClientpackRequest,
)
from cohesivenet.models.update_config_request import UpdateConfigRequest
from cohesivenet.models.update_configure_container_system_request import (
    UpdateConfigureContainerSystemRequest,
)
from cohesivenet.models.update_container_image_detail import UpdateContainerImageDetail
from cohesivenet.models.update_container_image_detail_response import (
    UpdateContainerImageDetailResponse,
)
from cohesivenet.models.update_container_image_request import (
    UpdateContainerImageRequest,
)
from cohesivenet.models.update_ipsec_address_request import UpdateIpsecAddressRequest
from cohesivenet.models.update_ipsec_connection_request import (
    UpdateIpsecConnectionRequest,
)
from cohesivenet.models.update_ipsec_tunnel_request import UpdateIpsecTunnelRequest
from cohesivenet.models.update_keyset_request import UpdateKeysetRequest
from cohesivenet.models.update_license_parameters_request import (
    UpdateLicenseParametersRequest,
)
from cohesivenet.models.update_password_request import UpdatePasswordRequest
from cohesivenet.models.update_peer_request import UpdatePeerRequest
from cohesivenet.models.update_remote_support_config_request import (
    UpdateRemoteSupportConfigRequest,
)
from cohesivenet.models.update_server_ssl_request import UpdateServerSSLRequest
from cohesivenet.models.upgrade_license_response import UpgradeLicenseResponse
from cohesivenet.models.upgrade_license_response_response import (
    UpgradeLicenseResponseResponse,
)
from cohesivenet.models.vns3_controller import VNS3Controller
from cohesivenet.models.vns3_controller_peer import VNS3ControllerPeer
from cohesivenet.models.webhook_custom_property import WebhookCustomProperty
from cohesivenet.models.webhook_detail_response import WebhookDetailResponse
from cohesivenet.models.webhook_header import WebhookHeader
from cohesivenet.models.webhook_integration import WebhookIntegration
from cohesivenet.models.webhook_parameter import WebhookParameter
from cohesivenet.models.webhooks_list_response import WebhooksListResponse



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class UpdateKeysetRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "source": "str",
        "token": "str",
        "topology_name": "str",
        "sealed_network": "bool",
    }

    attribute_map = {
        "source": "source",
        "token": "token",
        "topology_name": "topology_name",
        "sealed_network": "sealed_network",
    }

    def __init__(
        self, source=None, token=None, topology_name=None, sealed_network=None
    ):  # noqa: E501
        """UpdateKeysetRequest - a model defined in OpenAPI"""  # noqa: E501

        self._source = None
        self._token = None
        self._topology_name = None
        self._sealed_network = None
        self.discriminator = None

        if source is not None:
            self.source = source
        self.token = token
        if topology_name is not None:
            self.topology_name = topology_name
        if sealed_network is not None:
            self.sealed_network = sealed_network

    @property
    def source(self):
        """Gets the source of this UpdateKeysetRequest.  # noqa: E501

        If provided, fetches keyset from source manager  # noqa: E501

        :return: The source of this UpdateKeysetRequest.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this UpdateKeysetRequest.

        If provided, fetches keyset from source manager  # noqa: E501

        :param source: The source of this UpdateKeysetRequest.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def token(self):
        """Gets the token of this UpdateKeysetRequest.  # noqa: E501

        Arbitrary key used to help randomize the checksum, it must be identical for each manager in a topology.  # noqa: E501

        :return: The token of this UpdateKeysetRequest.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this UpdateKeysetRequest.

        Arbitrary key used to help randomize the checksum, it must be identical for each manager in a topology.  # noqa: E501

        :param token: The token of this UpdateKeysetRequest.  # noqa: E501
        :type: str
        """
        if token is None:
            raise ValueError(
                "Invalid value for `token`, must not be `None`"
            )  # noqa: E501

        self._token = token

    @property
    def topology_name(self):
        """Gets the topology_name of this UpdateKeysetRequest.  # noqa: E501

        Name for the topology  # noqa: E501

        :return: The topology_name of this UpdateKeysetRequest.  # noqa: E501
        :rtype: str
        """
        return self._topology_name

    @topology_name.setter
    def topology_name(self, topology_name):
        """Sets the topology_name of this UpdateKeysetRequest.

        Name for the topology  # noqa: E501

        :param topology_name: The topology_name of this UpdateKeysetRequest.  # noqa: E501
        :type: str
        """

        self._topology_name = topology_name

    @property
    def sealed_network(self):
        """Gets the sealed_network of this UpdateKeysetRequest.  # noqa: E501

        UPDATEME  # noqa: E501

        :return: The sealed_network of this UpdateKeysetRequest.  # noqa: E501
        :rtype: bool
        """
        return self._sealed_network

    @sealed_network.setter
    def sealed_network(self, sealed_network):
        """Sets the sealed_network of this UpdateKeysetRequest.

        UPDATEME  # noqa: E501

        :param sealed_network: The sealed_network of this UpdateKeysetRequest.  # noqa: E501
        :type: bool
        """

        self._sealed_network = sealed_network

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateKeysetRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class PeerSelfRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"id": "int", "force": "bool"}

    attribute_map = {"id": "id", "force": "force"}

    def __init__(self, id=None, force=None):  # noqa: E501
        """PeerSelfRequest - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._force = None
        self.discriminator = None

        self.id = id
        if force is not None:
            self.force = force

    @property
    def id(self):
        """Gets the id of this PeerSelfRequest.  # noqa: E501

        Cannot be the same as the id of another manager in the topology, and  cannot be greater than the number of controllers in the topology   # noqa: E501

        :return: The id of this PeerSelfRequest.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PeerSelfRequest.

        Cannot be the same as the id of another manager in the topology, and  cannot be greater than the number of controllers in the topology   # noqa: E501

        :param id: The id of this PeerSelfRequest.  # noqa: E501
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def force(self):
        """Gets the force of this PeerSelfRequest.  # noqa: E501


        :return: The force of this PeerSelfRequest.  # noqa: E501
        :rtype: bool
        """
        return self._force

    @force.setter
    def force(self, force):
        """Sets the force of this PeerSelfRequest.


        :param force: The force of this PeerSelfRequest.  # noqa: E501
        :type: bool
        """

        self._force = force

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PeerSelfRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
